@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
 our $DATE = '2015-06-18'; # DATE
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -118,7 +118,7 @@ sub pericmd_ok {
     subtest 'pericmd_ok test suite' => sub {
         $test_run->(
             name      => 'help action',
-            args      => {url=>'/Perinci/Examples/noop'},
+            args      => {url=>'/Perinci/Examples/Tiny/noop'},
             argv      => [qw/--help/],
             exit_code => 0,
             stdout_re => qr/- Do nothing.+^Other options:/ms,
@@ -151,7 +151,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.16 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-18.
+This document describes version 1.17 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-18.
 
 =head1 SEE ALSO
 
